defaultNLSStarts: Default combinations of starting values for nonlinear least...

Description Usage Arguments Value

Description

Default combinations of starting values for nonlinear least squares fitting of saturation curves

Usage

1

Arguments

maxsig

the maximum number of significant genes in the curve

Value

a list of lists, each of which serves as a set of starting parameter estimates for nls


StoreyLab/superSeq documentation built on June 4, 2019, 7:47 a.m.