fitnls: Fit significance curve using nonlinear least squares

Description Usage Arguments See Also

Description

Fit a nonlinear least squares model explaining the number of significant genes based on the proportion of reads used. Tries each of the starting combinations of parameters in the given order. If all fail, returns NULL.

Usage

1
2
fitnls(dat, method = "probit", starts = NULL,
  control = defaultNLSControl)

Arguments

dat

a data.frame from summary.subsamples, containing columns for "proportion" and "significant"

method

specifies the method used to fit the model. Default is probit (superSeq). "logit" and "smoother" are possible options but are mainly for use in our manuscript.

starts

A list of combinations of starting guesses to try with nls. If NULL, uses defaultNLSStarts

control

control for nls, by default defaultNLSControl

See Also

defaultNLSStarts


StoreyLab/superSeq documentation built on June 4, 2019, 7:47 a.m.