Description Usage Arguments Value
Default combinations of starting values for nonlinear least squares fitting of saturation curves
1 | defaultNLSStarts(maxsig)
|
maxsig |
the maximum number of significant genes in the curve |
a list of lists, each of which serves as a set of starting parameter estimates for nls
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.