Description Usage Arguments See Also
Fit a nonlinear least squares model explaining the number of significant genes based on the proportion of reads used. Tries each of the starting combinations of parameters in the given order. If all fail, returns NULL.
1 2 | fitnls(dat, method = "probit", starts = NULL,
control = defaultNLSControl)
|
dat |
a data.frame from summary.subsamples, containing columns for "proportion" and "significant" |
method |
specifies the method used to fit the model. Default is probit (superSeq). "logit" and "smoother" are possible options but are mainly for use in our manuscript. |
starts |
A list of combinations of starting guesses to try with
|
control |
control for |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.